@@ -4,8 +4,8 @@
 # Can only handle one client at a time.
 # 
 # WARNING: If you have more than one of these running on your network, send.pl
-# might connect to a server other than yours.  See the documentation for scopes
-# and domains, for details.
+# might connect to a server other than yours.  See the documentation for
+# scopes and domains, for details.
 
 use IO::Socket::TIPC;
 
@@ -16,9 +16,13 @@ my $sock = IO::Socket::TIPC->new(
 	LocalScope => 'zone',        # This affects where clients can connect from
 );
 
+print(STDERR "--- my local ID is ", $sock->getsockname()->stringify(), "\n");
 while(1) {
 	my $client = $sock->accept();
+	my $caddr = $client->getpeername();
+	print(STDERR "--- Got connection from ", $caddr->stringify(), "\n");
 	while(my $line = $client->getline()) {
 		print($line);
 	}
+	print(STDERR "--- Lost connection from ", $caddr->stringify(), "\n");
 }
